@@ -4,7 +4,7 @@ function(model, catvars) {
     yhat <- as.data.frame(fitted(model))
   } else if (class(model) == "clm") {
     predprob <- model$model[, 2:ncol(model$model)]
-    yhat <- predict(model, newdata = predprob, type = "prob")$fit
+    yhat <- as.data.frame(predict(model, newdata = predprob, type = "prob")$fit)
   } else warning("Model is not of class polr or clm. Test may fail.")
   formula <- formula(model$terms)
   DNAME <- paste("formula: ", deparse(formula))
